@@ -1,4 +1,4 @@
-"""gustaf/gustaf/mesh_maker.py
+"""gustaf/gustaf/mesh_maker.py.
 
 MeshMaker that triangulates and tetrahedralizes with segment input.
 """
