@@ -1,4 +1,4 @@
-"""gustaf/gustaf/segment.py
+"""gustaf/gustaf/segment.py.
 
 Segment class to form inputs for `triangle` and `tetgenpy`.
 """
