@@ -1,17 +1,15 @@
-"""
-gustaf/spline/proximity.py
+"""gustaf/spline/proximity.py.
 
 Closest what?
 """
 
 
 def closest_control_points(
-        spline,
-        query_points,
-        return_distances=False,
+    spline,
+    query_points,
+    return_distances=False,
 ):
-    """
-    Returns indices of closest control points
+    """Returns indices of closest control points.
 
     Parameters
     -----------
@@ -19,7 +17,7 @@ def closest_control_points(
     query_points: (n, spline.dim) np.ndarray
       float
     return_distances: bool
-      
+
     tolerance: float
       Default is settings.Tolerance. Only relevant iff nearest_only==False
 
@@ -43,19 +41,16 @@ def closest_control_points(
 
 
 def closest_parametric_coordinate(
-        spline,
-        query_points,
+    spline,
+    query_points,
 ):
-    """
-    Finds closest points using 
-    """
+    """Finds closest points using."""
     pass
 
-class _Proximity:
-    """
-    Helper class to allow direct proximity queries for spline obj (BSpline or
-    NURBS).
-    Internal use only.
+
+class Proximity:
+    """Helper class to allow direct proximity queries for spline obj (BSpline
+    or NURBS). Internal use only.
 
     Examples
     ---------
